.. include:: ../README.rst

Table of Contents
=================

.. toctree::
    :maxdepth: 4
    :hidden:

    self

.. toctree::
    :caption: Examples

    examples

.. toctree::
    :caption: API Reference
    :maxdepth: 3

    api

.. toctree::
    :caption: Tutorials

    1.5" & 2.4" Monochrome 128x64 OLED Display Module Guide <https://learn.adafruit.com/1-5-and-2-1-monochrome-128x64-oled-display-module>
    2.3" Monochrome 128x32 OLED Display Module Guide <https://learn.adafruit.com/2-3-monochrome-128x32-oled-display-module>
    Displayio Guide <https://learn.adafruit.com/circuitpython-display-support-using-displayio>

.. toctree::
    :caption: Related Products

    Monochrome 1.54" 128x64 OLED Graphic Display Module Kit <https://www.adafruit.com/product/2720>
    Monochrome 2.42" 128x64 OLED Graphic Display Module Kit  <https://www.adafruit.com/product/2719>
    Monochrome 2.3" 128x32 OLED Graphic Display Module Kit <https://www.adafruit.com/product/2675>

.. toctree::
    :caption: Other Links

    Download from GitHub <https://github.com/adafruit/Adafruit_CircuitPython_DisplayIO_SSD1305/releases/latest>
    Download Library Bundle <https://circuitpython.org/libraries>
    CircuitPython Reference Documentation <https://docs.circuitpython.org>
    CircuitPython Support Forum <https://forums.adafruit.com/viewforum.php?f=60>
    Discord Chat <https://adafru.it/discord>
    Adafruit Learning System <https://learn.adafruit.com>
    Adafruit Blog <https://blog.adafruit.com>
    Adafruit Store <https://www.adafruit.com>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
